///
/// This file is part of Rheolef.
///
/// Copyright (C) 2000-2009 Pierre Saramito <Pierre.Saramito@imag.fr>
///
/// Rheolef is free software; you can redistribute it and/or modify
/// it under the terms of the GNU General Public License as published by
/// the Free Software Foundation; either version 2 of the License, or
/// (at your option) any later version.
///
/// Rheolef is distributed in the hope that it will be useful,
/// but WITHOUT ANY WARRANTY; without even the implied warranty of
/// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
/// GNU General Public License for more details.
///
/// You should have received a copy of the GNU General Public License
/// along with Rheolef; if not, write to the Free Software
/// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
/// 
/// =========================================================================
#include "sqr.h"
namespace rheolef {
template <class T> T pythag(T a, T b) {
        T absa = fabs (a);
        T absb = fabs (b);
        if (absa > absb)     return absa*sqrt (1.0 + sqr (absb/absa));
        return (absb == T(0.0) ? T(0.0) : absb*sqrt (1.0 + sqr (absa/absb)));
}
} // namepace rheolef
